﻿using Microsoft.EntityFrameworkCore;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;

namespace Bedelia.EF
{
    public class BedeliaContext : DbContext
    {
        public DbSet<User> Users { get; set; }
        public DbSet<Course> Courses { get; set; }
        public DbSet<UserCourse> UserCourses { get; set; }

        public BedeliaContext(DbContextOptions options) : base(options) { }

        protected override void OnModelCreating(ModelBuilder modelBuilder)
        {
            modelBuilder.Entity<User>(e =>
            {
                e.HasKey(x => x.Id);

                e.HasIndex(x => x.IdentityCard)
                    .IsUnique();

                e.HasIndex(x => x.Name)
                    .IsUnique();

                e.Property(x => x.IdentityCard)
                    .IsRequired()
                    .HasMaxLength(50);

                e.Property(x => x.Name)
                    .IsRequired()
                    .HasMaxLength(50);

                e.Property(x => x.Password)
                    .IsRequired()
                    .HasMaxLength(255);
            });

            modelBuilder.Entity<Course>(e =>
            {
                e.HasKey(x => x.Id);

                e.Property(x => x.Name)
                .IsRequired()
                .HasMaxLength(50);
            });

            modelBuilder.Entity<UserCourse>(e =>
            {
                e.HasKey(x => new { x.UserId, x.CourseId });

                e.HasOne(x => x.Course)
                    .WithMany(x => x.UserCourses)
                    .HasForeignKey(x => x.CourseId);

                e.HasOne(x => x.User)
                    .WithMany(x => x.UserCourses)
                    .HasForeignKey(x => x.UserId);
            });
        }
    }
}
